@@ -3,7 +3,7 @@ package Thrall::Server;
 use strict;
 use warnings;
 
-our $VERSION = '0.0302';
+our $VERSION = '0.0303';
 
 use Config;
 
@@ -432,43 +432,40 @@ sub _handle_response {
             $send_headers{$lck} = $v;
         }
     }
-    if ( ! exists $send_headers{server} ) {
+    if (! exists $send_headers{server}) {
         unshift @lines, "Server: $self->{server_software}\015\012";
     }
-    if ( ! exists $send_headers{date} ) {
+    if (! exists $send_headers{date}) {
         unshift @lines, "Date: @{[HTTP::Date::time2str()]}\015\012";
     }
 
     # try to set content-length when keepalive can be used, or disable it
     my $use_chunked;
-    if ( $protocol eq 'HTTP/1.0' ) {
+    if (defined $protocol and $protocol eq 'HTTP/1.1') {
+        if (defined $send_headers{'content-length'}
+                || defined $send_headers{'transfer-encoding'}) {
+            # ok
+        } elsif (!Plack::Util::status_with_no_entity_body($status_code)) {
+            push @lines, "Transfer-Encoding: chunked\015\012";
+            $use_chunked = 1;
+        }
+        push @lines, "Connection: close\015\012" unless $$use_keepalive_r;
+    } else {
+        # HTTP/1.0
         if ($$use_keepalive_r) {
             if (defined $send_headers{'content-length'}
                 || defined $send_headers{'transfer-encoding'}) {
                 # ok
-            }
-            elsif ( ! Plack::Util::status_with_no_entity_body($status_code)
-                    && defined(my $cl = Plack::Util::content_length($body))) {
+            } elsif (! Plack::Util::status_with_no_entity_body($status_code)
+                     && defined(my $cl = Plack::Util::content_length($body))) {
                 push @lines, "Content-Length: $cl\015\012";
-            }
-            else {
+            } else {
                 $$use_keepalive_r = undef
             }
         }
         push @lines, "Connection: keep-alive\015\012" if $$use_keepalive_r;
         push @lines, "Connection: close\015\012" if !$$use_keepalive_r; #fmm..
     }
-    elsif ( $protocol eq 'HTTP/1.1' ) {
-        if (defined $send_headers{'content-length'}
-                || defined $send_headers{'transfer-encoding'}) {
-            # ok
-        } elsif ( !Plack::Util::status_with_no_entity_body($status_code) ) {
-            push @lines, "Transfer-Encoding: chunked\015\012";
-            $use_chunked = 1;
-        }
-        push @lines, "Connection: close\015\012" unless $$use_keepalive_r;
-
-    }
 
     unshift @lines, "HTTP/1.1 $status_code @{[ HTTP::Status::status_message($status_code) || 'Unknown' ]}\015\012";
     push @lines, "\015\012";
